@@ -12,6 +12,8 @@ from django.conf import settings
 from tendenci.core.base.http import Http403
 from tendenci.core.base.utils import now_localized
 from tendenci.core.perms.object_perms import ObjectPermission
+
+from tendenci.core.perms.decorators import is_enabled
 from tendenci.core.perms.utils import (update_perms_and_save, get_notice_recipients,
     has_perm, has_view_perm, get_query_filters)
 from tendenci.core.event_logs.models import EventLog
@@ -20,6 +22,7 @@ from tendenci.core.meta.forms import MetaForm
 from tendenci.core.site_settings.utils import get_setting
 from tendenci.core.theme.shortcuts import themed_response as render_to_response
 from tendenci.core.exports.utils import run_export_task
+from tendenci.apps.redirects.models import Redirect
 
 from tendenci.addons.resumes.models import Resume
 from tendenci.addons.resumes.forms import ResumeForm
@@ -29,20 +32,19 @@ try:
 except:
     notification = None
 
+
+@is_enabled('resumes')
 def index(request, slug=None, template_name="resumes/view.html"):
+    if not get_setting('module', 'resumes', 'enabled'):
+        redirect = get_object_or_404(Redirect, from_app='resumes')
+        return HttpResponseRedirect('/' + redirect.to_url)
+
     if not slug: return HttpResponseRedirect(reverse('resume.search'))
     resume = get_object_or_404(Resume, slug=slug)
     
     if has_view_perm(request.user,'resumes.view_resume',resume):
-        log_defaults = {
-            'event_id' : 355000,
-            'event_data': '%s (%d) viewed by %s' % (resume._meta.object_name, resume.pk, request.user),
-            'description': '%s viewed' % resume._meta.object_name,
-            'user': request.user,
-            'request': request,
-            'instance': resume,
-        }
-        EventLog.objects.log(**log_defaults)
+
+        EventLog.objects.log()
         return render_to_response(template_name, {'resume': resume}, 
             context_instance=RequestContext(request))
     else:
@@ -55,16 +57,8 @@ def resume_file(request, slug=None, template_name="resumes/view.html"):
 
     if has_view_perm(request.user,'resumes.view_resume',resume):
         if resume.resume_file:
-            log_defaults = {
-                'event_id' : 355000,
-                'event_data': '%s (%d) viewed by %s' % (resume._meta.object_name, resume.pk, request.user),
-                'description': '%s viewed' % resume._meta.object_name,
-                'user': request.user,
-                'request': request,
-                'instance': resume,
-            }
         
-            EventLog.objects.log(**log_defaults)
+            EventLog.objects.log(instance=resume)
             response = HttpResponse(resume.resume_file)
             response['Content-Disposition'] = 'attachment; filename=%s' % (os.path.basename(unicode(resume.resume_file)))
 
@@ -74,6 +68,8 @@ def resume_file(request, slug=None, template_name="resumes/view.html"):
     else:
         raise Http403
 
+
+@is_enabled('resumes')
 def search(request, template_name="resumes/search.html"):
     """
     This page lists out all resumes from newest to oldest.
@@ -111,18 +107,12 @@ def search_redirect(request):
     """
     return HttpResponseRedirect(reverse('resumes'))
 
+
+@is_enabled('resumes')
 def print_view(request, slug, template_name="resumes/print-view.html"):
     resume = get_object_or_404(Resume, slug=slug)    
 
-    log_defaults = {
-        'event_id' : 355001,
-        'event_data': '%s (%d) viewed by %s' % (resume._meta.object_name, resume.pk, request.user),
-        'description': '%s viewed - print view' % resume._meta.object_name,
-        'user': request.user,
-        'request': request,
-        'instance': resume,
-    }
-    EventLog.objects.log(**log_defaults)
+    EventLog.objects.log(instance=resume)
        
     if has_view_perm(request.user,'resumes.view_resume',resume):
         return render_to_response(template_name, {'resume': resume}, 
@@ -130,9 +120,10 @@ def print_view(request, slug, template_name="resumes/print-view.html"):
     else:
         raise Http403
 
+
+@is_enabled('resumes')
 @login_required
 def add(request, form_class=ResumeForm, template_name="resumes/add.html"):
-
     can_add_active = has_perm(request.user, 'resumes.add_resume')
 
     if request.method == "POST":
@@ -156,15 +147,7 @@ def add(request, form_class=ResumeForm, template_name="resumes/add.html"):
                 resume.resume_file.file.seek(0)
                 resume.save()
 
-            log_defaults = {
-                'event_id' : 351000,
-                'event_data': '%s (%d) added by %s' % (resume._meta.object_name, resume.pk, request.user),
-                'description': '%s added' % resume._meta.object_name,
-                'user': request.user,
-                'request': request,
-                'instance': resume,
-            }
-            EventLog.objects.log(**log_defaults)
+            EventLog.objects.log(instance=resume)
 
             if request.user.is_authenticated():
                 messages.add_message(request, messages.SUCCESS, 'Successfully added %s' % resume)
@@ -188,6 +171,8 @@ def add(request, form_class=ResumeForm, template_name="resumes/add.html"):
     return render_to_response(template_name, {'form':form},
         context_instance=RequestContext(request))
 
+
+@is_enabled('resumes')
 @login_required
 def edit(request, id, form_class=ResumeForm, template_name="resumes/edit.html"):
     resume = get_object_or_404(Resume, pk=id)
@@ -202,15 +187,7 @@ def edit(request, id, form_class=ResumeForm, template_name="resumes/edit.html"):
                     resume.resume_file.file.seek(0)
                 resume = update_perms_and_save(request, form, resume)
 
-                log_defaults = {
-                    'event_id' : 352000,
-                    'event_data': '%s (%d) edited by %s' % (resume._meta.object_name, resume.pk, request.user),
-                    'description': '%s edited' % resume._meta.object_name,
-                    'user': request.user,
-                    'request': request,
-                    'instance': resume,
-                }
-                EventLog.objects.log(**log_defaults) 
+                EventLog.objects.log(instance=resume) 
                 
                 messages.add_message(request, messages.SUCCESS, 'Successfully updated %s' % resume)
                                                               
@@ -221,9 +198,10 @@ def edit(request, id, form_class=ResumeForm, template_name="resumes/edit.html"):
     else:
         raise Http403
 
+
+@is_enabled('resumes')
 @login_required
 def edit_meta(request, id, form_class=MetaForm, template_name="resumes/edit-meta.html"):
-
     # check permission
     resume = get_object_or_404(Resume, pk=id)
     if not has_perm(request.user,'resumes.change_resume',resume):
@@ -253,22 +231,16 @@ def edit_meta(request, id, form_class=MetaForm, template_name="resumes/edit-meta
     return render_to_response(template_name, {'resume': resume, 'form':form}, 
         context_instance=RequestContext(request))
 
+
+@is_enabled('resumes')
 @login_required
 def delete(request, id, template_name="resumes/delete.html"):
     resume = get_object_or_404(Resume, pk=id)
 
     if has_perm(request.user,'resumes.delete_resume'):   
         if request.method == "POST":
-            log_defaults = {
-                'event_id' : 433000,
-                'event_data': '%s (%d) deleted by %s' % (resume._meta.object_name, resume.pk, request.user),
-                'description': '%s deleted' % resume._meta.object_name,
-                'user': request.user,
-                'request': request,
-                'instance': resume,
-            }
             
-            EventLog.objects.log(**log_defaults)
+            EventLog.objects.log(instance=resume)
             messages.add_message(request, messages.SUCCESS, 'Successfully deleted %s' % resume)
             
             # send notification to administrators
@@ -290,6 +262,8 @@ def delete(request, id, template_name="resumes/delete.html"):
     else:
         raise Http403
 
+
+@is_enabled('resumes')
 @login_required
 def pending(request, template_name="resumes/pending.html"):
     if not request.user.profile.is_superuser:
@@ -298,6 +272,7 @@ def pending(request, template_name="resumes/pending.html"):
     return render_to_response(template_name, {'resumes': resumes},
             context_instance=RequestContext(request))
 
+
 @login_required
 def approve(request, id, template_name="resumes/approve.html"):
     if not request.user.profile.is_superuser:
@@ -330,10 +305,11 @@ def approve(request, id, template_name="resumes/approve.html"):
 def thank_you(request, template_name="resumes/thank-you.html"):
     return render_to_response(template_name, {}, context_instance=RequestContext(request))
 
+
+@is_enabled('resumes')
 @login_required
 def export(request, template_name="resumes/export.html"):
     """Export Resumes"""
-    
     if not request.user.is_superuser:
         raise Http403
     
